#!/bin/csh

setenv OSSYS `uname -s`

unsetenv PYTHONHOME
unsetenv PYTHONSTARTUP

setenv PYPREFIX /Users/local/CarPy
setenv PREFIX ${PYPREFIX}/builds
setenv SRC ${PREFIX}/src

if ($OSSYS == 'Darwin') then
  setenv NP `/usr/sbin/sysctl -n hw.availcpu`
  setenv ARCHSYS `uname -s`
  setenv ARCHMODEL `uname -m`
  setenv OSVER `sw_vers -productVersion | /usr/bin/python -ESc "import sys; print '.'.join(sys.stdin.read().split('.')[:2])"`
  if (! ${?PYTHONBASE} ) then
     setenv PYTHONBASE ${PREFIX}/${ARCHSYS}.${OSVER}.${ARCHMODEL}
  endif
  if (! -d $PYTHONBASE ) then
     echo "Error.  Folder $PYTHONBASE does not exist.  You likely don't have"
     echo "the correct binary release.  Try building from source or explicitly"
     echo "set the PYTHONBASE environment variable."
  endif

  setenv MAKES ${PYTHONBASE}.makes
  setenv MACOSX_DEPLOYMENT_TARGET 10.6
  setenv DYLD_FALLBACK_LIBRARY_PATH .:${PYTHONBASE}/lib:${PYTHONBASE}/lib/pgplot:${PYTHONBASE}/lib/vtk-5.3
  setenv LD_LIBRARY_PATH ${DYLD_FALLBACK_LIBRARY_PATH}

  setenv VERSION `/usr/bin/python -c 'import sys,os; print os.path.basename(os.path.realpath(os.environ["PYTHONBASE"]+"/Python.framework/Versions/Current"))'`
  setenv PYTHONFBASE ${PYTHONBASE}/Python.framework/Versions/${VERSION}
  setenv PYTHONWEXECUTABLE ${PYTHONFBASE}/Resources/Python.app/Contents/MacOS/Python

  setenv PYTHONLIB ${PYTHONFBASE}/lib/python${VERSION}
  setenv PYTHONINC ${PYTHONFBASE}/include/python${VERSION}
  setenv PYTHONSITE ${PYTHONFBASE}/lib/python${VERSION}/site-packages

  setenv PATH ${PYTHONBASE}/bin:${PYTHONFBASE}/bin:${PYPREFIX}/dist/bin_local:${PYPREFIX}/dist/bin:${PYPREFIX}/dist/bin_oldnumeric:${PATH}

else if ($OSSYS == 'Linux') then
  setenv NP `grep processor /proc/cpuinfo | wc -l`
  setenv ARCHSYS `lsb_release -i -s`
  setenv ARCHMODEL `arch`
  setenv OSVER `lsb_release -r -s`
  setenv ARCHMHZ `grep -m 1 'cpu MHz' /proc/cpuinfo | sed -e 's/.*://g' -e 's/ //g'`
  setenv ARCHBIT `uname -m | sed -e 's/i686/32/' -e 's/x86_64/64/'`
  if (! ${?PYTHONBASE} ) then
     setenv PYTHONBASE ${PREFIX}/${ARCHSYS}.${OSVER}.${ARCHMODEL}
  endif
  if (! -d $PYTHONBASE ) then
     echo "Error.  Folder $PYTHONBASE does not exist.  You likely don't have"
     echo "the correct binary release.  Try building from source or explicitly"
     echo "set the PYTHONBASE environment variable."
     exit
  endif
  setenv MAKES ${PYTHONBASE}.makes
  setenv LD_LIBRARY_PATH ${PYTHONBASE}/lib:${PYTHONBASE}/lib/pgplot:${PYTHONBASE}/lib/vtk-5.3

  setenv VERSION `${PYTHONBASE}/bin/python -c 'import sys; print "%d.%d" % sys.version_info[:2]'`

  setenv PYTHONLIB ${PYTHONBASE}/lib/python${VERSION}
  setenv PYTHONINC ${PYTHONBASE}/include/python${VERSION}
  setenv PYTHONSITE ${PYTHONBASE}/lib/python${VERSION}/site-packages

  setenv PATH ${PYTHONBASE}/bin:${PYPREFIX}/dist/bin_local:${PYPREFIX}/dist/bin:${PYPREFIX}/dist/bin_oldnumeric:${PATH}

endif

setenv PGPLOT_DIR ${PYTHONBASE}/lib/pgplot
setenv PGPLOT_FONT ${PGPLOT_DIR}/grfont.dat
setenv PGPLOT_DEV /xs
setenv PGPLOT_SIZE 8.5

setenv BUILDS ${PYTHONBASE}/builds

setenv NUMDIR ${PYTHONSITE}/numpy/core/include/

setenv PYTHONPATH .:${PYPREFIX}/dist/lib_local:${PYPREFIX}/dist/lib:${PYPREFIX}/dist/lib_oldnumeric

setenv PYTHONDATA ${PYPREFIX}/datafiles

